@@ -33,11 +33,12 @@ class Publish:
         print(sh.poetry("publish"))
         print(sh.git("commit", "-a", "-m", "Bump version in pyproject.toml"))
         print(sh.git("push"))
-        version = sh.poetry("version", "-s")
-        asset = sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"), "-n1")
+        version = str(sh.poetry("version", "-s")).strip()
+        asset = str(sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"),
+                    "-n1")).strip()
         print(sh.gh("release", "create", version, f"dist/{asset}"))
         print(sh.git("pull"))
-        print("Published v{version}!")
+        print("Published release {version}!")
         return 0
 
 
